"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
function _client() {
  const data = require("@nocobase/client");
  _client = function _client() {
    return data;
  };
  return data;
}
var _CollectionBlockInitializer = require("../../components/CollectionBlockInitializer");
var _variable = require("../../variable");
var _locale = require("../../locale");
var _SchemaConfig = require("./SchemaConfig");
var _ModeConfig = require("./ModeConfig");
var _AssigneesSelect = require("./AssigneesSelect");
const MULTIPLE_ASSIGNED_MODE = {
  SINGLE: Symbol('single'),
  ALL: Symbol('all'),
  ANY: Symbol('any'),
  ALL_PERCENTAGE: Symbol('all percentage'),
  ANY_PERCENTAGE: Symbol('any percentage')
};
// TODO(optimize): change to register way
const initializerGroup = _client().BlockInitializers.items.find(group => group.key === 'media');
if (!initializerGroup.children.find(item => item.key === 'workflowTodos')) {
  initializerGroup.children.push({
    key: 'workflowTodos',
    type: 'item',
    title: `{{t("Workflow todos", { ns: "${_locale.NAMESPACE}" })}}`,
    component: 'WorkflowTodoBlockInitializer',
    icon: 'CheckSquareOutlined'
  });
}
var _default = {
  title: `{{t("Manual", { ns: "${_locale.NAMESPACE}" })}}`,
  type: 'manual',
  group: 'manual',
  description: `{{t("Could be used for manually submitting data, and determine whether to continue or exit. Workflow will generate a todo item for assigned user when it reaches a manual node, and continue processing after user submits the form.", { ns: "${_locale.NAMESPACE}" })}}`,
  fieldset: {
    assignees: {
      type: 'array',
      title: `{{t("Assignees", { ns: "${_locale.NAMESPACE}" })}}`,
      'x-decorator': 'FormItem',
      'x-component': 'AssigneesSelect',
      'x-component-props': {
        // multiple: true,
      },
      required: true,
      default: []
    },
    mode: {
      type: 'number',
      title: `{{t("Mode", { ns: "${_locale.NAMESPACE}" })}}`,
      'x-decorator': 'FormItem',
      'x-component': 'ModeConfig',
      default: 1,
      'x-reactions': {
        dependencies: ['assignees'],
        fulfill: {
          state: {
            visible: '{{$deps[0].length > 1}}'
          }
        }
      }
    },
    schema: {
      type: 'void',
      title: `{{t("User interface", { ns: "${_locale.NAMESPACE}" })}}`,
      'x-decorator': 'FormItem',
      'x-component': 'SchemaConfigButton',
      properties: {
        schema: {
          type: 'object',
          'x-component': 'SchemaConfig',
          default: null
        }
      }
    },
    forms: {
      type: 'object',
      default: {}
    }
  },
  view: {},
  scope: {},
  components: {
    SchemaConfigButton: _SchemaConfig.SchemaConfigButton,
    SchemaConfig: _SchemaConfig.SchemaConfig,
    ModeConfig: _ModeConfig.ModeConfig,
    AssigneesSelect: _AssigneesSelect.AssigneesSelect
  },
  useVariables({
    config
  }, {
    types
  }) {
    var _config$forms;
    const formKeys = Object.keys((_config$forms = config.forms) !== null && _config$forms !== void 0 ? _config$forms : {});
    if (!formKeys.length) {
      return null;
    }
    const options = formKeys.map(formKey => {
      var _form$collection;
      const form = config.forms[formKey];
      // eslint-disable-next-line react-hooks/rules-of-hooks
      const options = (0, _variable.useCollectionFieldOptions)({
        fields: (_form$collection = form.collection) === null || _form$collection === void 0 ? void 0 : _form$collection.fields,
        collection: form.collection,
        types
      });
      return options.length ? {
        key: formKey,
        value: formKey,
        label: form.title || formKey,
        title: form.title || formKey,
        children: options
      } : null;
    }).filter(Boolean);
    return options.length ? options : null;
  },
  useInitializers(node) {
    var _node$config$forms;
    const _useCollectionManager = (0, _client().useCollectionManager)(),
      getCollection = _useCollectionManager.getCollection;
    const formKeys = Object.keys((_node$config$forms = node.config.forms) !== null && _node$config$forms !== void 0 ? _node$config$forms : {});
    if (!formKeys.length || node.config.mode) {
      return null;
    }
    const forms = formKeys.map(formKey => {
      var _form$title;
      const form = node.config.forms[formKey];
      const _getCollection = getCollection(form.collection),
        _getCollection$fields = _getCollection.fields,
        fields = _getCollection$fields === void 0 ? [] : _getCollection$fields;
      return fields.length ? {
        type: 'item',
        title: (_form$title = form.title) !== null && _form$title !== void 0 ? _form$title : formKey,
        component: _CollectionBlockInitializer.CollectionBlockInitializer,
        collection: form.collection,
        dataSource: `{{$jobsMapByNodeId.${node.id}.${formKey}}}`
      } : null;
    }).filter(Boolean);
    return forms.length ? {
      key: 'forms',
      type: 'subMenu',
      title: node.title,
      children: forms
    } : null;
  },
  initializers: {}
};
exports.default = _default;